rm(list=ls())

setwd("... votre rpertoire de travail ...")

#installation de la librairie
#une seule fois
#install.packages("RGoogleAnalytics")

#chargement de la librairie
# chaque utilisation
library(RGoogleAnalytics)

#identifiants
#client_id <- "xxxxxxxxxxxxx.apps.googleusercontent.com"
#client_secret <- "xxxxxxxxxxxxxxxx" 

#generation d'un token
#oauth_token <- Auth(client.id = client_id, client.secret = client_secret)

#sauvegarde du token
#save(oauth_token,file = "oauth_token")

#chargement du token
load("oauth_token")

#validation pour une session d'analyse
ValidateToken(oauth_token)

#paramtrer la requte
query.list <- Init(start.date = "2017-11-01",
                   end.date = "2017-11-30",
                   dimensions = "ga:date",
                   metrics = "ga:sessions,ga:users",
                   max.results = 10000,
                   sort = "-ga:date",
                   table.id = "ga:TABLE_ID_DE_VOTRE_SITE")

#valider la requte
ga.query <- QueryBuilder(query.list)

#rcuprer les donnes
ga.data <- GetReportData(ga.query,oauth_token,split_daywise = TRUE)

#type d'objet obtenu
print(class(ga.data))

#afficher les premires lignes
print(head(ga.data))

#library(xlsx)
#sauver les donnes
#write.xlsx(ga.data,"results.xlsx",sheetName="Query_1")

#sommes mensuelles
print(sapply(ga.data[c("sessions","users")],sum))

#graphique des sessions
plot(1:30,rev(ga.data$sessions),type="b",xlab="Day",ylab="Sessions",main="November 2017")

#paramtrage : sessions par pays
query.list.pays <- Init(start.date = "2017-11-01",
                   end.date = "2017-11-30",
                   dimensions = "ga:country",
                   metrics = "ga:sessions",
                   max.results = 10000,
                   sort = "-ga:sessions",
                   table.id = "ga:TABLE_ID_DE_VOTRE_SITE")

#validation
ga.query.pays <- QueryBuilder(query.list.pays)

#rsultat
ga.data.pays <- GetReportData(ga.query.pays,oauth_token)

#vrification dimension
print(dim(ga.data.pays))

#10 premiers pays
print(head(ga.data.pays,10))

#sauvegarde
#write.xlsx(ga.data.pays,"results.xlsx",sheetName="Query_2",append=T)

#paramtrage : sessions par page
query.list.page <- Init(start.date = "2017-11-01",
                        end.date = "2017-11-30",
                        dimensions = "ga:pageTitle",
                        metrics = "ga:sessions",
                        max.results = 10000,
                        sort = "-ga:sessions",
                        table.id = "ga:TABLE_ID_DE_VOTRE_SITE")

#validation
ga.query.page <- QueryBuilder(query.list.page)

#rsultat
ga.data.page <- GetReportData(ga.query.page,oauth_token)

#sauvegarde
#write.xlsx(ga.data.page,"results.xlsx",sheetName="Query_3",append=T)

#affichage des 10 pages les plus populaires
print(head(ga.data.page,10))

#les 3 premires concentrent...
print(sum(ga.data.page$sessions[1:3])/18708)

#croisement pays - page
query.list.pp <- Init(start.date = "2017-11-01",
                        end.date = "2017-11-30",
                        dimensions = "ga:country,ga:pageTitle",
                        metrics = "ga:sessions",
                        max.results = 10000,
                        sort = "-ga:sessions",
                        table.id = "ga:TABLE_ID_DE_VOTRE_SITE")

#validation
ga.query.pp <- QueryBuilder(query.list.pp)

#rsultat
ga.data.pp <- GetReportData(ga.query.pp,oauth_token)

#sauvegarde
#write.xlsx(ga.data.pp,"results.xlsx",sheetName="Query_4",append=T)

#les 5 premires
print(head(ga.data.pp,5))

#tableau crois des pays et pages
TC <- xtabs(sessions ~ country + pageTitle, data = ga.data.pp)

#restriction aux 10 pays et 10 pages les plus reprsents
TC10x10 <- TC[ga.data.pays$country[1:10],ga.data.page$pageTitle[1:10]]

#renommage des colonnes
colnames(TC10x10) <- c("R","DataScience","Python","Econometrie","Tutos","Excel","RegLog","TanagraEN","TanagraFR","MasterSISE")

#affichage
print(TC10x10)

#sauvegarde
#TB <- data.frame(TC10x10)
#write.xlsx(TB,"results.xlsx",sheetName="Croisement",append=T)

#librairie "ca"
library(ca)

#AFC
afc <- ca(TC10x10,nd=2)
print(afc)

#reprsentation simultane
plot(afc)

#tableau restreint
TC2 <- TC10x10[-c(6,10),-8]
print(TC2)

#afc de nouveau
afc2 <- ca(TC2,nd=2)
print(afc2)

#plotting
plot(afc2,xlim=c(-0.4,0.4),ylim=c(-0.4,0.4))
